#!/bin/sh

# This helper script will handle deploying a s3 bucket
set -e

source /scripts/utils.sh
source /scripts/terraform.sh


check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

# Sets the terraform variables that have dependencies on other sub-charts
# and could not be set from the values file at the time of installation.
echo "the glue role is ${glueJobRoleArn}"
echo "glue_job_role_arn = \"$gluejobRoleArn\" " >> ${tfAdditionalVarsFile}
echo "glue_job_role_name = \"$gluejobRoleName\" " >> ${tfAdditionalVarsFile}

#adds the iam policy prefix
echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

# Sets the terraform variable for s3 script location for glue
echo "glue_job_script_location = \"s3://${scriptLocationBucket}${scriptPath}\"" >> ${tfAdditionalVarsFile}

#adds the chart dependant glue job arguments
if [ ! -z "${jobArguments}" ]; then
  echo "The job arguments are ${jobArguments}"
  jobArguments=$(echo ${jobArguments} | jq -r '.[].jobArgumentName')
  cprint "The arguments are $jobArguments"
  cprint "Starting configmap mounting var setup.."
  for var in ${jobArguments}; do
    key="--${var}"
    # Find the mounted configmap variable
    value=$(printenv "${var}")
    # Create a template for assembling the map
    varTemplate='"%s":"%s",'
    jsonString=$(printf "${varTemplate}" "${key}" "${value}")
    # Append the template via the loop
    FILES+=${jsonString}
  done
  # Add brackets around at the end.
  output=$(echo {${FILES}})
  echo "glue_job_arguments = ${output}" >> ${tfAdditionalVarsFile}
fi

#adds the cloudwatch event parameters if required
if [ ${enableCloudwatch}  == true ]; then
  if [ -z "${targetArn}" ]; then
  echo "Cloudwatch events is enabled but target arn not specified"
  exit 1
  fi

  echo "target_arn = \"${targetArn}\"" >> ${tfAdditionalVarsFile}
fi

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get glue_job_policy_arn accessPolicyValue
terraform_get glue_job_events_policy_arn eventsPolicyValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  AccessPolicy: ${accessPolicyValue}
  EventsPolicy: ${eventsPolicyValue}

EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
